# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SymmetricKeyRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'derive_symmetric_key_ids': 'list[str]',
        'delivery_public_key_ids': 'list[str]',
        'key_derivation_service_id': 'str',
        'creation_time': 'int',
        'symmetric_key_length': 'int',
        'packaged_ciphertext_version': 'int',
        'must_sign_delivered_symmetric_keys': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'derive_symmetric_key_ids': 'deriveSymmetricKeyIds',
        'delivery_public_key_ids': 'deliveryPublicKeyIds',
        'key_derivation_service_id': 'keyDerivationServiceId',
        'creation_time': 'creationTime',
        'symmetric_key_length': 'symmetricKeyLength',
        'packaged_ciphertext_version': 'packagedCiphertextVersion',
        'must_sign_delivered_symmetric_keys': 'mustSignDeliveredSymmetricKeys'
    }

    def __init__(self, id=None, derive_symmetric_key_ids=None, delivery_public_key_ids=None, key_derivation_service_id=None, creation_time=None, symmetric_key_length=None, packaged_ciphertext_version=None, must_sign_delivered_symmetric_keys=None):  # noqa: E501
        """SymmetricKeyRequest - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._derive_symmetric_key_ids = None
        self._delivery_public_key_ids = None
        self._key_derivation_service_id = None
        self._creation_time = None
        self._symmetric_key_length = None
        self._packaged_ciphertext_version = None
        self._must_sign_delivered_symmetric_keys = None
        self.discriminator = None

        self.id = id
        self.derive_symmetric_key_ids = derive_symmetric_key_ids
        self.delivery_public_key_ids = delivery_public_key_ids
        self.key_derivation_service_id = key_derivation_service_id
        self.creation_time = creation_time
        self.symmetric_key_length = symmetric_key_length
        self.packaged_ciphertext_version = packaged_ciphertext_version
        self.must_sign_delivered_symmetric_keys = must_sign_delivered_symmetric_keys

    @property
    def id(self):
        """Gets the id of this SymmetricKeyRequest.  # noqa: E501

        Id of the symmetric key request.  # noqa: E501

        :return: The id of this SymmetricKeyRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SymmetricKeyRequest.

        Id of the symmetric key request.  # noqa: E501

        :param id: The id of this SymmetricKeyRequest.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def derive_symmetric_key_ids(self):
        """Gets the derive_symmetric_key_ids of this SymmetricKeyRequest.  # noqa: E501

        These are the keyId's of for the symmetric keys to actually derive.  # noqa: E501

        :return: The derive_symmetric_key_ids of this SymmetricKeyRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._derive_symmetric_key_ids

    @derive_symmetric_key_ids.setter
    def derive_symmetric_key_ids(self, derive_symmetric_key_ids):
        """Sets the derive_symmetric_key_ids of this SymmetricKeyRequest.

        These are the keyId's of for the symmetric keys to actually derive.  # noqa: E501

        :param derive_symmetric_key_ids: The derive_symmetric_key_ids of this SymmetricKeyRequest.  # noqa: E501
        :type: list[str]
        """
        if derive_symmetric_key_ids is None:
            raise ValueError("Invalid value for `derive_symmetric_key_ids`, must not be `None`")  # noqa: E501

        self._derive_symmetric_key_ids = derive_symmetric_key_ids

    @property
    def delivery_public_key_ids(self):
        """Gets the delivery_public_key_ids of this SymmetricKeyRequest.  # noqa: E501

        These are the keyId's to deliver all of the derived symmetric keys.  # noqa: E501

        :return: The delivery_public_key_ids of this SymmetricKeyRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._delivery_public_key_ids

    @delivery_public_key_ids.setter
    def delivery_public_key_ids(self, delivery_public_key_ids):
        """Sets the delivery_public_key_ids of this SymmetricKeyRequest.

        These are the keyId's to deliver all of the derived symmetric keys.  # noqa: E501

        :param delivery_public_key_ids: The delivery_public_key_ids of this SymmetricKeyRequest.  # noqa: E501
        :type: list[str]
        """
        if delivery_public_key_ids is None:
            raise ValueError("Invalid value for `delivery_public_key_ids`, must not be `None`")  # noqa: E501

        self._delivery_public_key_ids = delivery_public_key_ids

    @property
    def key_derivation_service_id(self):
        """Gets the key_derivation_service_id of this SymmetricKeyRequest.  # noqa: E501

        The serviceId that must generate these keys.  # noqa: E501

        :return: The key_derivation_service_id of this SymmetricKeyRequest.  # noqa: E501
        :rtype: str
        """
        return self._key_derivation_service_id

    @key_derivation_service_id.setter
    def key_derivation_service_id(self, key_derivation_service_id):
        """Sets the key_derivation_service_id of this SymmetricKeyRequest.

        The serviceId that must generate these keys.  # noqa: E501

        :param key_derivation_service_id: The key_derivation_service_id of this SymmetricKeyRequest.  # noqa: E501
        :type: str
        """
        if key_derivation_service_id is None:
            raise ValueError("Invalid value for `key_derivation_service_id`, must not be `None`")  # noqa: E501

        self._key_derivation_service_id = key_derivation_service_id

    @property
    def creation_time(self):
        """Gets the creation_time of this SymmetricKeyRequest.  # noqa: E501

        Epoch time of the symmetric key requestion request time.  # noqa: E501

        :return: The creation_time of this SymmetricKeyRequest.  # noqa: E501
        :rtype: int
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this SymmetricKeyRequest.

        Epoch time of the symmetric key requestion request time.  # noqa: E501

        :param creation_time: The creation_time of this SymmetricKeyRequest.  # noqa: E501
        :type: int
        """
        if creation_time is None:
            raise ValueError("Invalid value for `creation_time`, must not be `None`")  # noqa: E501

        self._creation_time = creation_time

    @property
    def symmetric_key_length(self):
        """Gets the symmetric_key_length of this SymmetricKeyRequest.  # noqa: E501

        Length in bytes of the derived symmetric keys.  # noqa: E501

        :return: The symmetric_key_length of this SymmetricKeyRequest.  # noqa: E501
        :rtype: int
        """
        return self._symmetric_key_length

    @symmetric_key_length.setter
    def symmetric_key_length(self, symmetric_key_length):
        """Sets the symmetric_key_length of this SymmetricKeyRequest.

        Length in bytes of the derived symmetric keys.  # noqa: E501

        :param symmetric_key_length: The symmetric_key_length of this SymmetricKeyRequest.  # noqa: E501
        :type: int
        """
        if symmetric_key_length is None:
            raise ValueError("Invalid value for `symmetric_key_length`, must not be `None`")  # noqa: E501

        self._symmetric_key_length = symmetric_key_length

    @property
    def packaged_ciphertext_version(self):
        """Gets the packaged_ciphertext_version of this SymmetricKeyRequest.  # noqa: E501

        After deriving symmetric keys, this determines the ciphertext packaging scheme required for encrypted key delivery.  # noqa: E501

        :return: The packaged_ciphertext_version of this SymmetricKeyRequest.  # noqa: E501
        :rtype: int
        """
        return self._packaged_ciphertext_version

    @packaged_ciphertext_version.setter
    def packaged_ciphertext_version(self, packaged_ciphertext_version):
        """Sets the packaged_ciphertext_version of this SymmetricKeyRequest.

        After deriving symmetric keys, this determines the ciphertext packaging scheme required for encrypted key delivery.  # noqa: E501

        :param packaged_ciphertext_version: The packaged_ciphertext_version of this SymmetricKeyRequest.  # noqa: E501
        :type: int
        """
        if packaged_ciphertext_version is None:
            raise ValueError("Invalid value for `packaged_ciphertext_version`, must not be `None`")  # noqa: E501

        self._packaged_ciphertext_version = packaged_ciphertext_version

    @property
    def must_sign_delivered_symmetric_keys(self):
        """Gets the must_sign_delivered_symmetric_keys of this SymmetricKeyRequest.  # noqa: E501

        If true the key deriver must sign delivered symmetric keys ciphertext blobs  # noqa: E501

        :return: The must_sign_delivered_symmetric_keys of this SymmetricKeyRequest.  # noqa: E501
        :rtype: bool
        """
        return self._must_sign_delivered_symmetric_keys

    @must_sign_delivered_symmetric_keys.setter
    def must_sign_delivered_symmetric_keys(self, must_sign_delivered_symmetric_keys):
        """Sets the must_sign_delivered_symmetric_keys of this SymmetricKeyRequest.

        If true the key deriver must sign delivered symmetric keys ciphertext blobs  # noqa: E501

        :param must_sign_delivered_symmetric_keys: The must_sign_delivered_symmetric_keys of this SymmetricKeyRequest.  # noqa: E501
        :type: bool
        """
        if must_sign_delivered_symmetric_keys is None:
            raise ValueError("Invalid value for `must_sign_delivered_symmetric_keys`, must not be `None`")  # noqa: E501

        self._must_sign_delivered_symmetric_keys = must_sign_delivered_symmetric_keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SymmetricKeyRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SymmetricKeyRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from peacemakr.generated.api_client import ApiClient


class OrgApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_admin_to_org(self, contact, **kwargs):  # noqa: E501
        """Add a new admin to this org  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_admin_to_org(contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Contact contact: (required)
        :return: Contact
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_admin_to_org_with_http_info(contact, **kwargs)  # noqa: E501
        else:
            (data) = self.add_admin_to_org_with_http_info(contact, **kwargs)  # noqa: E501
            return data

    def add_admin_to_org_with_http_info(self, contact, **kwargs):  # noqa: E501
        """Add a new admin to this org  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_admin_to_org_with_http_info(contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Contact contact: (required)
        :return: Contact
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['contact']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_admin_to_org" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'contact' is set
        if ('contact' not in params or
                params['contact'] is None):
            raise ValueError("Missing the required parameter `contact` when calling `add_admin_to_org`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contact' in params:
            body_params = params['contact']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/admin', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Contact',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_api_key_to_org(self, **kwargs):  # noqa: E501
        """Add a new API Key to an org  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_api_key_to_org(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: APIKey
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_api_key_to_org_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_api_key_to_org_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_api_key_to_org_with_http_info(self, **kwargs):  # noqa: E501
        """Add a new API Key to an org  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_api_key_to_org_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: APIKey
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_api_key_to_org" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/key', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='APIKey',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_organization(self, id_token, stripe_customer_id, org_name, contact, **kwargs):  # noqa: E501
        """Create a new organization. Must be an authenticated request with a valid id_token from a trusted IdP.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_organization(id_token, stripe_customer_id, org_name, contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id_token: (required)
        :param str stripe_customer_id: (required)
        :param str org_name: (required)
        :param Contact contact: (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_organization_with_http_info(id_token, stripe_customer_id, org_name, contact, **kwargs)  # noqa: E501
        else:
            (data) = self.add_organization_with_http_info(id_token, stripe_customer_id, org_name, contact, **kwargs)  # noqa: E501
            return data

    def add_organization_with_http_info(self, id_token, stripe_customer_id, org_name, contact, **kwargs):  # noqa: E501
        """Create a new organization. Must be an authenticated request with a valid id_token from a trusted IdP.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_organization_with_http_info(id_token, stripe_customer_id, org_name, contact, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id_token: (required)
        :param str stripe_customer_id: (required)
        :param str org_name: (required)
        :param Contact contact: (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id_token', 'stripe_customer_id', 'org_name', 'contact']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_organization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id_token' is set
        if ('id_token' not in params or
                params['id_token'] is None):
            raise ValueError("Missing the required parameter `id_token` when calling `add_organization`")  # noqa: E501
        # verify the required parameter 'stripe_customer_id' is set
        if ('stripe_customer_id' not in params or
                params['stripe_customer_id'] is None):
            raise ValueError("Missing the required parameter `stripe_customer_id` when calling `add_organization`")  # noqa: E501
        # verify the required parameter 'org_name' is set
        if ('org_name' not in params or
                params['org_name'] is None):
            raise ValueError("Missing the required parameter `org_name` when calling `add_organization`")  # noqa: E501
        # verify the required parameter 'contact' is set
        if ('contact' not in params or
                params['contact'] is None):
            raise ValueError("Missing the required parameter `contact` when calling `add_organization`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id_token' in params:
            query_params.append(('id_token', params['id_token']))  # noqa: E501
        if 'stripe_customer_id' in params:
            query_params.append(('stripeCustomerId', params['stripe_customer_id']))  # noqa: E501
        if 'org_name' in params:
            query_params.append(('orgName', params['org_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contact' in params:
            body_params = params['contact']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_admin_from_org(self, email, **kwargs):  # noqa: E501
        """Remove an existing admin from the org (You can not remove the last admin. It will faile with a Bad Request response.)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_admin_from_org(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_admin_from_org_with_http_info(email, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_admin_from_org_with_http_info(email, **kwargs)  # noqa: E501
            return data

    def delete_admin_from_org_with_http_info(self, email, **kwargs):  # noqa: E501
        """Remove an existing admin from the org (You can not remove the last admin. It will faile with a Bad Request response.)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_admin_from_org_with_http_info(email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str email: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_admin_from_org" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'email' is set
        if ('email' not in params or
                params['email'] is None):
            raise ValueError("Missing the required parameter `email` when calling `delete_admin_from_org`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'email' in params:
            path_params['email'] = params['email']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/admin/{email}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_api_key_from_org(self, apikey, **kwargs):  # noqa: E501
        """Remove an existing API Key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_api_key_from_org(apikey, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str apikey: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_api_key_from_org_with_http_info(apikey, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_api_key_from_org_with_http_info(apikey, **kwargs)  # noqa: E501
            return data

    def delete_api_key_from_org_with_http_info(self, apikey, **kwargs):  # noqa: E501
        """Remove an existing API Key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_api_key_from_org_with_http_info(apikey, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str apikey: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['apikey']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_api_key_from_org" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'apikey' is set
        if ('apikey' not in params or
                params['apikey'] is None):
            raise ValueError("Missing the required parameter `apikey` when calling `delete_api_key_from_org`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'apikey' in params:
            path_params['apikey'] = params['apikey']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/key/{apikey}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_organization(self, org_id, **kwargs):  # noqa: E501
        """Remove an existing organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_organization(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_organization_with_http_info(org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_organization_with_http_info(org_id, **kwargs)  # noqa: E501
            return data

    def delete_organization_with_http_info(self, org_id, **kwargs):  # noqa: E501
        """Remove an existing organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_organization_with_http_info(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_organization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `delete_organization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/{orgId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cloud_organization_api_key(self, **kwargs):  # noqa: E501
        """Get an access key for the peacemakr shared cloud org (all cloud key derivers must use this)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cloud_organization_api_key(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: APIKey
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_cloud_organization_api_key_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_cloud_organization_api_key_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_cloud_organization_api_key_with_http_info(self, **kwargs):  # noqa: E501
        """Get an access key for the peacemakr shared cloud org (all cloud key derivers must use this)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cloud_organization_api_key_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: APIKey
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cloud_organization_api_key" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/key/sharedCloud', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='APIKey',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_organization(self, org_id, **kwargs):  # noqa: E501
        """Get an existing organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_organization(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_organization_with_http_info(org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_organization_with_http_info(org_id, **kwargs)  # noqa: E501
            return data

    def get_organization_with_http_info(self, org_id, **kwargs):  # noqa: E501
        """Get an existing organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_organization_with_http_info(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organization" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `get_organization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/{orgId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_organization_from_api_key(self, apikey, **kwargs):  # noqa: E501
        """Get an existing Organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_organization_from_api_key(apikey, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str apikey: (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_organization_from_api_key_with_http_info(apikey, **kwargs)  # noqa: E501
        else:
            (data) = self.get_organization_from_api_key_with_http_info(apikey, **kwargs)  # noqa: E501
            return data

    def get_organization_from_api_key_with_http_info(self, apikey, **kwargs):  # noqa: E501
        """Get an existing Organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_organization_from_api_key_with_http_info(apikey, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str apikey: (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['apikey']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organization_from_api_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'apikey' is set
        if ('apikey' not in params or
                params['apikey'] is None):
            raise ValueError("Missing the required parameter `apikey` when calling `get_organization_from_api_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'apikey' in params:
            path_params['apikey'] = params['apikey']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/key/{apikey}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_test_organization_api_key(self, **kwargs):  # noqa: E501
        """Get an ephemeral test org api key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_test_organization_api_key(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: APIKey
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_test_organization_api_key_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_test_organization_api_key_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_test_organization_api_key_with_http_info(self, **kwargs):  # noqa: E501
        """Get an ephemeral test org api key  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_test_organization_api_key_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: APIKey
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_test_organization_api_key" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/org/key/test', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='APIKey',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_stripe_customer_id(self, stripe_customer_id, **kwargs):  # noqa: E501
        """Update the stripe customer Id associated with this account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_stripe_customer_id(stripe_customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str stripe_customer_id: (required)
        :return: APIKey
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_stripe_customer_id_with_http_info(stripe_customer_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_stripe_customer_id_with_http_info(stripe_customer_id, **kwargs)  # noqa: E501
            return data

    def update_stripe_customer_id_with_http_info(self, stripe_customer_id, **kwargs):  # noqa: E501
        """Update the stripe customer Id associated with this account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_stripe_customer_id_with_http_info(stripe_customer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str stripe_customer_id: (required)
        :return: APIKey
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['stripe_customer_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_stripe_customer_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'stripe_customer_id' is set
        if ('stripe_customer_id' not in params or
                params['stripe_customer_id'] is None):
            raise ValueError("Missing the required parameter `stripe_customer_id` when calling `update_stripe_customer_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'stripe_customer_id' in params:
            query_params.append(('stripeCustomerId', params['stripe_customer_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/org/stripeId', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='APIKey',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from peacemakr.generated.api.client_api import ClientApi
from peacemakr.generated.api.crypto_config_api import CryptoConfigApi
from peacemakr.generated.api.key_derivation_service_registry_api import KeyDerivationServiceRegistryApi
from peacemakr.generated.api.key_service_api import KeyServiceApi
from peacemakr.generated.api.login_api import LoginApi
from peacemakr.generated.api.org_api import OrgApi
from peacemakr.generated.api.phone_home_api import PhoneHomeApi
from peacemakr.generated.api.server_management_api import ServerManagementApi



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import peacemakr
from peacemakr.generated.api.key_service_api import KeyServiceApi  # noqa: E501
from peacemakr.generated.rest import ApiException


class TestKeyServiceApi(unittest.TestCase):
    """KeyServiceApi unit test stubs"""

    def setUp(self):
        self.api = peacemakr.generated.api.key_service_api.KeyServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_encrypted_keys(self):
        """Test case for get_all_encrypted_keys

        Get all encrypted symmetric keys that are encrypted with this encrypting keyId, optionally limiting the request to a set of symmetric key domains  # noqa: E501
        """
        pass

    def test_get_public_key(self):
        """Test case for get_public_key

        Get the public key associated with the passed-in key ID  # noqa: E501
        """
        pass

    def test_post_new_encrypted_keys(self):
        """Test case for post_new_encrypted_keys

        Add a new encrypted key. The encrypting key that protects the encrypted key is identified with encryptingKeyId. Request must come from a registered key manager.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from peacemakr.generated.models.symmetric_key_use_domain import SymmetricKeyUseDomain  # noqa: F401,E501


class CryptoConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'symmetric_key_use_domains': 'list[SymmetricKeyUseDomain]',
        'symmetric_key_use_domain_selector_scheme': 'str',
        'owner_org_id': 'str',
        'client_key_type': 'str',
        'client_key_bitlength': 'int',
        'client_key_ttl': 'int'
    }

    attribute_map = {
        'id': 'id',
        'symmetric_key_use_domains': 'symmetricKeyUseDomains',
        'symmetric_key_use_domain_selector_scheme': 'symmetricKeyUseDomainSelectorScheme',
        'owner_org_id': 'ownerOrgId',
        'client_key_type': 'clientKeyType',
        'client_key_bitlength': 'clientKeyBitlength',
        'client_key_ttl': 'clientKeyTTL'
    }

    def __init__(self, id=None, symmetric_key_use_domains=None, symmetric_key_use_domain_selector_scheme=None, owner_org_id=None, client_key_type=None, client_key_bitlength=None, client_key_ttl=None):  # noqa: E501
        """CryptoConfig - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._symmetric_key_use_domains = None
        self._symmetric_key_use_domain_selector_scheme = None
        self._owner_org_id = None
        self._client_key_type = None
        self._client_key_bitlength = None
        self._client_key_ttl = None
        self.discriminator = None

        self.id = id
        self.symmetric_key_use_domains = symmetric_key_use_domains
        self.symmetric_key_use_domain_selector_scheme = symmetric_key_use_domain_selector_scheme
        self.owner_org_id = owner_org_id
        self.client_key_type = client_key_type
        self.client_key_bitlength = client_key_bitlength
        self.client_key_ttl = client_key_ttl

    @property
    def id(self):
        """Gets the id of this CryptoConfig.  # noqa: E501


        :return: The id of this CryptoConfig.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CryptoConfig.


        :param id: The id of this CryptoConfig.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def symmetric_key_use_domains(self):
        """Gets the symmetric_key_use_domains of this CryptoConfig.  # noqa: E501

        every application layer encryption must select a key to use from one specific active semmetric key encryption domain. this is an array of encryption domains id's that are currently available for encryption  # noqa: E501

        :return: The symmetric_key_use_domains of this CryptoConfig.  # noqa: E501
        :rtype: list[SymmetricKeyUseDomain]
        """
        return self._symmetric_key_use_domains

    @symmetric_key_use_domains.setter
    def symmetric_key_use_domains(self, symmetric_key_use_domains):
        """Sets the symmetric_key_use_domains of this CryptoConfig.

        every application layer encryption must select a key to use from one specific active semmetric key encryption domain. this is an array of encryption domains id's that are currently available for encryption  # noqa: E501

        :param symmetric_key_use_domains: The symmetric_key_use_domains of this CryptoConfig.  # noqa: E501
        :type: list[SymmetricKeyUseDomain]
        """
        if symmetric_key_use_domains is None:
            raise ValueError("Invalid value for `symmetric_key_use_domains`, must not be `None`")  # noqa: E501

        self._symmetric_key_use_domains = symmetric_key_use_domains

    @property
    def symmetric_key_use_domain_selector_scheme(self):
        """Gets the symmetric_key_use_domain_selector_scheme of this CryptoConfig.  # noqa: E501

        to guide SDK's on how to select an encryption domain, a selectorScheme helps an SDK map a encryption request to a set of keys and encryption algoritm  # noqa: E501

        :return: The symmetric_key_use_domain_selector_scheme of this CryptoConfig.  # noqa: E501
        :rtype: str
        """
        return self._symmetric_key_use_domain_selector_scheme

    @symmetric_key_use_domain_selector_scheme.setter
    def symmetric_key_use_domain_selector_scheme(self, symmetric_key_use_domain_selector_scheme):
        """Sets the symmetric_key_use_domain_selector_scheme of this CryptoConfig.

        to guide SDK's on how to select an encryption domain, a selectorScheme helps an SDK map a encryption request to a set of keys and encryption algoritm  # noqa: E501

        :param symmetric_key_use_domain_selector_scheme: The symmetric_key_use_domain_selector_scheme of this CryptoConfig.  # noqa: E501
        :type: str
        """
        if symmetric_key_use_domain_selector_scheme is None:
            raise ValueError("Invalid value for `symmetric_key_use_domain_selector_scheme`, must not be `None`")  # noqa: E501

        self._symmetric_key_use_domain_selector_scheme = symmetric_key_use_domain_selector_scheme

    @property
    def owner_org_id(self):
        """Gets the owner_org_id of this CryptoConfig.  # noqa: E501

        the org id of the organization that owns these symmetric keys  # noqa: E501

        :return: The owner_org_id of this CryptoConfig.  # noqa: E501
        :rtype: str
        """
        return self._owner_org_id

    @owner_org_id.setter
    def owner_org_id(self, owner_org_id):
        """Sets the owner_org_id of this CryptoConfig.

        the org id of the organization that owns these symmetric keys  # noqa: E501

        :param owner_org_id: The owner_org_id of this CryptoConfig.  # noqa: E501
        :type: str
        """
        if owner_org_id is None:
            raise ValueError("Invalid value for `owner_org_id`, must not be `None`")  # noqa: E501

        self._owner_org_id = owner_org_id

    @property
    def client_key_type(self):
        """Gets the client_key_type of this CryptoConfig.  # noqa: E501

        the type of key that should be associated with clients, for example, rsa  # noqa: E501

        :return: The client_key_type of this CryptoConfig.  # noqa: E501
        :rtype: str
        """
        return self._client_key_type

    @client_key_type.setter
    def client_key_type(self, client_key_type):
        """Sets the client_key_type of this CryptoConfig.

        the type of key that should be associated with clients, for example, rsa  # noqa: E501

        :param client_key_type: The client_key_type of this CryptoConfig.  # noqa: E501
        :type: str
        """
        if client_key_type is None:
            raise ValueError("Invalid value for `client_key_type`, must not be `None`")  # noqa: E501

        self._client_key_type = client_key_type

    @property
    def client_key_bitlength(self):
        """Gets the client_key_bitlength of this CryptoConfig.  # noqa: E501

        the bit length of all new client keys, for example, 2048  # noqa: E501

        :return: The client_key_bitlength of this CryptoConfig.  # noqa: E501
        :rtype: int
        """
        return self._client_key_bitlength

    @client_key_bitlength.setter
    def client_key_bitlength(self, client_key_bitlength):
        """Sets the client_key_bitlength of this CryptoConfig.

        the bit length of all new client keys, for example, 2048  # noqa: E501

        :param client_key_bitlength: The client_key_bitlength of this CryptoConfig.  # noqa: E501
        :type: int
        """
        if client_key_bitlength is None:
            raise ValueError("Invalid value for `client_key_bitlength`, must not be `None`")  # noqa: E501

        self._client_key_bitlength = client_key_bitlength

    @property
    def client_key_ttl(self):
        """Gets the client_key_ttl of this CryptoConfig.  # noqa: E501

        the TTL on the client's local asymetric key  # noqa: E501

        :return: The client_key_ttl of this CryptoConfig.  # noqa: E501
        :rtype: int
        """
        return self._client_key_ttl

    @client_key_ttl.setter
    def client_key_ttl(self, client_key_ttl):
        """Sets the client_key_ttl of this CryptoConfig.

        the TTL on the client's local asymetric key  # noqa: E501

        :param client_key_ttl: The client_key_ttl of this CryptoConfig.  # noqa: E501
        :type: int
        """
        if client_key_ttl is None:
            raise ValueError("Invalid value for `client_key_ttl`, must not be `None`")  # noqa: E501

        self._client_key_ttl = client_key_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CryptoConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CryptoConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from peacemakr.generated.models.organization import Organization  # noqa: F401,E501


class LoginResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'must_create_org': 'bool',
        'message_ofthe_day': 'str',
        'org': 'Organization'
    }

    attribute_map = {
        'must_create_org': 'mustCreateOrg',
        'message_ofthe_day': 'messageOftheDay',
        'org': 'Org'
    }

    def __init__(self, must_create_org=None, message_ofthe_day=None, org=None):  # noqa: E501
        """LoginResponse - a model defined in Swagger"""  # noqa: E501

        self._must_create_org = None
        self._message_ofthe_day = None
        self._org = None
        self.discriminator = None

        if must_create_org is not None:
            self.must_create_org = must_create_org
        if message_ofthe_day is not None:
            self.message_ofthe_day = message_ofthe_day
        if org is not None:
            self.org = org

    @property
    def must_create_org(self):
        """Gets the must_create_org of this LoginResponse.  # noqa: E501

        if true, then the user is not attached to an existing org, and must create a new org  # noqa: E501

        :return: The must_create_org of this LoginResponse.  # noqa: E501
        :rtype: bool
        """
        return self._must_create_org

    @must_create_org.setter
    def must_create_org(self, must_create_org):
        """Sets the must_create_org of this LoginResponse.

        if true, then the user is not attached to an existing org, and must create a new org  # noqa: E501

        :param must_create_org: The must_create_org of this LoginResponse.  # noqa: E501
        :type: bool
        """

        self._must_create_org = must_create_org

    @property
    def message_ofthe_day(self):
        """Gets the message_ofthe_day of this LoginResponse.  # noqa: E501

        if set, please display this message to the user on login  # noqa: E501

        :return: The message_ofthe_day of this LoginResponse.  # noqa: E501
        :rtype: str
        """
        return self._message_ofthe_day

    @message_ofthe_day.setter
    def message_ofthe_day(self, message_ofthe_day):
        """Sets the message_ofthe_day of this LoginResponse.

        if set, please display this message to the user on login  # noqa: E501

        :param message_ofthe_day: The message_ofthe_day of this LoginResponse.  # noqa: E501
        :type: str
        """

        self._message_ofthe_day = message_ofthe_day

    @property
    def org(self):
        """Gets the org of this LoginResponse.  # noqa: E501


        :return: The org of this LoginResponse.  # noqa: E501
        :rtype: Organization
        """
        return self._org

    @org.setter
    def org(self, org):
        """Sets the org of this LoginResponse.


        :param org: The org of this LoginResponse.  # noqa: E501
        :type: Organization
        """

        self._org = org

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LoginResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LoginResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PublicKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'creation_time': 'int',
        'key_type': 'str',
        'encoding': 'str',
        'key': 'str',
        'owning_client_id': 'str',
        'owning_org_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'creation_time': 'creationTime',
        'key_type': 'keyType',
        'encoding': 'encoding',
        'key': 'key',
        'owning_client_id': 'owningClientId',
        'owning_org_id': 'owningOrgId'
    }

    def __init__(self, id=None, creation_time=None, key_type=None, encoding=None, key=None, owning_client_id=None, owning_org_id=None):  # noqa: E501
        """PublicKey - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._creation_time = None
        self._key_type = None
        self._encoding = None
        self._key = None
        self._owning_client_id = None
        self._owning_org_id = None
        self.discriminator = None

        self.id = id
        self.creation_time = creation_time
        self.key_type = key_type
        self.encoding = encoding
        self.key = key
        if owning_client_id is not None:
            self.owning_client_id = owning_client_id
        if owning_org_id is not None:
            self.owning_org_id = owning_org_id

    @property
    def id(self):
        """Gets the id of this PublicKey.  # noqa: E501


        :return: The id of this PublicKey.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublicKey.


        :param id: The id of this PublicKey.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def creation_time(self):
        """Gets the creation_time of this PublicKey.  # noqa: E501


        :return: The creation_time of this PublicKey.  # noqa: E501
        :rtype: int
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this PublicKey.


        :param creation_time: The creation_time of this PublicKey.  # noqa: E501
        :type: int
        """
        if creation_time is None:
            raise ValueError("Invalid value for `creation_time`, must not be `None`")  # noqa: E501

        self._creation_time = creation_time

    @property
    def key_type(self):
        """Gets the key_type of this PublicKey.  # noqa: E501


        :return: The key_type of this PublicKey.  # noqa: E501
        :rtype: str
        """
        return self._key_type

    @key_type.setter
    def key_type(self, key_type):
        """Sets the key_type of this PublicKey.


        :param key_type: The key_type of this PublicKey.  # noqa: E501
        :type: str
        """
        if key_type is None:
            raise ValueError("Invalid value for `key_type`, must not be `None`")  # noqa: E501

        self._key_type = key_type

    @property
    def encoding(self):
        """Gets the encoding of this PublicKey.  # noqa: E501


        :return: The encoding of this PublicKey.  # noqa: E501
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this PublicKey.


        :param encoding: The encoding of this PublicKey.  # noqa: E501
        :type: str
        """
        if encoding is None:
            raise ValueError("Invalid value for `encoding`, must not be `None`")  # noqa: E501

        self._encoding = encoding

    @property
    def key(self):
        """Gets the key of this PublicKey.  # noqa: E501


        :return: The key of this PublicKey.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this PublicKey.


        :param key: The key of this PublicKey.  # noqa: E501
        :type: str
        """
        if key is None:
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    @property
    def owning_client_id(self):
        """Gets the owning_client_id of this PublicKey.  # noqa: E501

        the id of the client that owns this specific public key  # noqa: E501

        :return: The owning_client_id of this PublicKey.  # noqa: E501
        :rtype: str
        """
        return self._owning_client_id

    @owning_client_id.setter
    def owning_client_id(self, owning_client_id):
        """Sets the owning_client_id of this PublicKey.

        the id of the client that owns this specific public key  # noqa: E501

        :param owning_client_id: The owning_client_id of this PublicKey.  # noqa: E501
        :type: str
        """

        self._owning_client_id = owning_client_id

    @property
    def owning_org_id(self):
        """Gets the owning_org_id of this PublicKey.  # noqa: E501

        the id of the org that owns the client that owns this specific public key  # noqa: E501

        :return: The owning_org_id of this PublicKey.  # noqa: E501
        :rtype: str
        """
        return self._owning_org_id

    @owning_org_id.setter
    def owning_org_id(self, owning_org_id):
        """Sets the owning_org_id of this PublicKey.

        the id of the org that owns the client that owns this specific public key  # noqa: E501

        :param owning_org_id: The owning_org_id of this PublicKey.  # noqa: E501
        :type: str
        """

        self._owning_org_id = owning_org_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PublicKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from abc import ABC, abstractmethod

class Persister(ABC):

    @abstractmethod
    def save(self, key, value):
        pass

    @abstractmethod
    def load(self, key):
        pass

    @abstractmethod
    def exists(self, key):
        pass



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class EncryptedSymmetricKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key_ids': 'list[str]',
        'key_length': 'int',
        'symmetric_key_use_domain_id': 'str',
        'packaged_ciphertext': 'str'
    }

    attribute_map = {
        'key_ids': 'keyIds',
        'key_length': 'keyLength',
        'symmetric_key_use_domain_id': 'symmetricKeyUseDomainId',
        'packaged_ciphertext': 'packagedCiphertext'
    }

    def __init__(self, key_ids=None, key_length=None, symmetric_key_use_domain_id=None, packaged_ciphertext=None):  # noqa: E501
        """EncryptedSymmetricKey - a model defined in Swagger"""  # noqa: E501

        self._key_ids = None
        self._key_length = None
        self._symmetric_key_use_domain_id = None
        self._packaged_ciphertext = None
        self.discriminator = None

        self.key_ids = key_ids
        self.key_length = key_length
        self.symmetric_key_use_domain_id = symmetric_key_use_domain_id
        self.packaged_ciphertext = packaged_ciphertext

    @property
    def key_ids(self):
        """Gets the key_ids of this EncryptedSymmetricKey.  # noqa: E501

        id's of the symmetric keys encrypted in packedCiphertext  # noqa: E501

        :return: The key_ids of this EncryptedSymmetricKey.  # noqa: E501
        :rtype: list[str]
        """
        return self._key_ids

    @key_ids.setter
    def key_ids(self, key_ids):
        """Sets the key_ids of this EncryptedSymmetricKey.

        id's of the symmetric keys encrypted in packedCiphertext  # noqa: E501

        :param key_ids: The key_ids of this EncryptedSymmetricKey.  # noqa: E501
        :type: list[str]
        """
        if key_ids is None:
            raise ValueError("Invalid value for `key_ids`, must not be `None`")  # noqa: E501

        self._key_ids = key_ids

    @property
    def key_length(self):
        """Gets the key_length of this EncryptedSymmetricKey.  # noqa: E501

        length of the keys encrypted in packedCiphertext  # noqa: E501

        :return: The key_length of this EncryptedSymmetricKey.  # noqa: E501
        :rtype: int
        """
        return self._key_length

    @key_length.setter
    def key_length(self, key_length):
        """Sets the key_length of this EncryptedSymmetricKey.

        length of the keys encrypted in packedCiphertext  # noqa: E501

        :param key_length: The key_length of this EncryptedSymmetricKey.  # noqa: E501
        :type: int
        """
        if key_length is None:
            raise ValueError("Invalid value for `key_length`, must not be `None`")  # noqa: E501

        self._key_length = key_length

    @property
    def symmetric_key_use_domain_id(self):
        """Gets the symmetric_key_use_domain_id of this EncryptedSymmetricKey.  # noqa: E501

        id of the symmetric key use domain which contains this key  # noqa: E501

        :return: The symmetric_key_use_domain_id of this EncryptedSymmetricKey.  # noqa: E501
        :rtype: str
        """
        return self._symmetric_key_use_domain_id

    @symmetric_key_use_domain_id.setter
    def symmetric_key_use_domain_id(self, symmetric_key_use_domain_id):
        """Sets the symmetric_key_use_domain_id of this EncryptedSymmetricKey.

        id of the symmetric key use domain which contains this key  # noqa: E501

        :param symmetric_key_use_domain_id: The symmetric_key_use_domain_id of this EncryptedSymmetricKey.  # noqa: E501
        :type: str
        """
        if symmetric_key_use_domain_id is None:
            raise ValueError("Invalid value for `symmetric_key_use_domain_id`, must not be `None`")  # noqa: E501

        self._symmetric_key_use_domain_id = symmetric_key_use_domain_id

    @property
    def packaged_ciphertext(self):
        """Gets the packaged_ciphertext of this EncryptedSymmetricKey.  # noqa: E501

        the actual packaged ciphertext of the encrypted symmetric key, of key  # noqa: E501

        :return: The packaged_ciphertext of this EncryptedSymmetricKey.  # noqa: E501
        :rtype: str
        """
        return self._packaged_ciphertext

    @packaged_ciphertext.setter
    def packaged_ciphertext(self, packaged_ciphertext):
        """Sets the packaged_ciphertext of this EncryptedSymmetricKey.

        the actual packaged ciphertext of the encrypted symmetric key, of key  # noqa: E501

        :param packaged_ciphertext: The packaged_ciphertext of this EncryptedSymmetricKey.  # noqa: E501
        :type: str
        """
        if packaged_ciphertext is None:
            raise ValueError("Invalid value for `packaged_ciphertext`, must not be `None`")  # noqa: E501

        self._packaged_ciphertext = packaged_ciphertext

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EncryptedSymmetricKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EncryptedSymmetricKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import peacemakr
from peacemakr.generated.api.login_api import LoginApi  # noqa: E501
from peacemakr.generated.rest import ApiException


class TestLoginApi(unittest.TestCase):
    """LoginApi unit test stubs"""

    def setUp(self):
        self.api = peacemakr.generated.api.login_api.LoginApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_login(self):
        """Test case for login

        After aquiring and OAuth2 openId id_token from IdP (like google login), present it here and proceed with the required flow.  If this is a new user, they'll have to create an org, else, they will just get their org details, and an APIKey associated with their org.  # noqa: E501
        """
        pass

    def test_login_invite_user(self):
        """Test case for login_invite_user

        Invite (bind) an existing user that is not already bound to an org, to your org  # noqa: E501
        """
        pass

    def test_login_uninvite_user(self):
        """Test case for login_uninvite_user

        Uninvite (remove) an existing user that is part of your org  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import peacemakr
from peacemakr.generated.api.org_api import OrgApi  # noqa: E501
from peacemakr.generated.rest import ApiException


class TestOrgApi(unittest.TestCase):
    """OrgApi unit test stubs"""

    def setUp(self):
        self.api = peacemakr.generated.api.org_api.OrgApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_admin_to_org(self):
        """Test case for add_admin_to_org

        Add a new admin to this org  # noqa: E501
        """
        pass

    def test_add_api_key_to_org(self):
        """Test case for add_api_key_to_org

        Add a new API Key to an org  # noqa: E501
        """
        pass

    def test_add_organization(self):
        """Test case for add_organization

        Create a new organization. Must be an authenticated request with a valid id_token from a trusted IdP.  # noqa: E501
        """
        pass

    def test_delete_admin_from_org(self):
        """Test case for delete_admin_from_org

        Remove an existing admin from the org (You can not remove the last admin. It will faile with a Bad Request response.)  # noqa: E501
        """
        pass

    def test_delete_api_key_from_org(self):
        """Test case for delete_api_key_from_org

        Remove an existing API Key  # noqa: E501
        """
        pass

    def test_delete_organization(self):
        """Test case for delete_organization

        Remove an existing organization  # noqa: E501
        """
        pass

    def test_get_cloud_organization_api_key(self):
        """Test case for get_cloud_organization_api_key

        Get an access key for the peacemakr shared cloud org (all cloud key derivers must use this)  # noqa: E501
        """
        pass

    def test_get_organization(self):
        """Test case for get_organization

        Get an existing organization  # noqa: E501
        """
        pass

    def test_get_organization_from_api_key(self):
        """Test case for get_organization_from_api_key

        Get an existing Organization  # noqa: E501
        """
        pass

    def test_get_test_organization_api_key(self):
        """Test case for get_test_organization_api_key

        Get an ephemeral test org api key  # noqa: E501
        """
        pass

    def test_update_stripe_customer_id(self):
        """Test case for update_stripe_customer_id

        Update the stripe customer Id associated with this account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from peacemakr.generated.api_client import ApiClient


class CryptoConfigApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_existing_use_domain(self, crypto_config_id, use_domain_id, **kwargs):  # noqa: E501
        """Add an existing use domain to another crypto config.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_existing_use_domain(crypto_config_id, use_domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :param str use_domain_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_existing_use_domain_with_http_info(crypto_config_id, use_domain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_existing_use_domain_with_http_info(crypto_config_id, use_domain_id, **kwargs)  # noqa: E501
            return data

    def add_existing_use_domain_with_http_info(self, crypto_config_id, use_domain_id, **kwargs):  # noqa: E501
        """Add an existing use domain to another crypto config.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_existing_use_domain_with_http_info(crypto_config_id, use_domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :param str use_domain_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['crypto_config_id', 'use_domain_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_existing_use_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'crypto_config_id' is set
        if ('crypto_config_id' not in params or
                params['crypto_config_id'] is None):
            raise ValueError("Missing the required parameter `crypto_config_id` when calling `add_existing_use_domain`")  # noqa: E501
        # verify the required parameter 'use_domain_id' is set
        if ('use_domain_id' not in params or
                params['use_domain_id'] is None):
            raise ValueError("Missing the required parameter `use_domain_id` when calling `add_existing_use_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'crypto_config_id' in params:
            path_params['cryptoConfigId'] = params['crypto_config_id']  # noqa: E501
        if 'use_domain_id' in params:
            path_params['useDomainId'] = params['use_domain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/config/{cryptoConfigId}/useDomain/{useDomainId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_use_domain(self, crypto_config_id, new_use_domain, **kwargs):  # noqa: E501
        """Add a new active use domain and attached it to the crypto config.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_use_domain(crypto_config_id, new_use_domain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :param SymmetricKeyUseDomain new_use_domain: (required)
        :return: SymmetricKeyUseDomain
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_use_domain_with_http_info(crypto_config_id, new_use_domain, **kwargs)  # noqa: E501
        else:
            (data) = self.add_use_domain_with_http_info(crypto_config_id, new_use_domain, **kwargs)  # noqa: E501
            return data

    def add_use_domain_with_http_info(self, crypto_config_id, new_use_domain, **kwargs):  # noqa: E501
        """Add a new active use domain and attached it to the crypto config.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_use_domain_with_http_info(crypto_config_id, new_use_domain, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :param SymmetricKeyUseDomain new_use_domain: (required)
        :return: SymmetricKeyUseDomain
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['crypto_config_id', 'new_use_domain']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_use_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'crypto_config_id' is set
        if ('crypto_config_id' not in params or
                params['crypto_config_id'] is None):
            raise ValueError("Missing the required parameter `crypto_config_id` when calling `add_use_domain`")  # noqa: E501
        # verify the required parameter 'new_use_domain' is set
        if ('new_use_domain' not in params or
                params['new_use_domain'] is None):
            raise ValueError("Missing the required parameter `new_use_domain` when calling `add_use_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'crypto_config_id' in params:
            path_params['cryptoConfigId'] = params['crypto_config_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_use_domain' in params:
            body_params = params['new_use_domain']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/config/{cryptoConfigId}/useDomain', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SymmetricKeyUseDomain',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_crypto_config(self, crypto_config_id, **kwargs):  # noqa: E501
        """Get the crypto configurations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_crypto_config(crypto_config_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :return: CryptoConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_crypto_config_with_http_info(crypto_config_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_crypto_config_with_http_info(crypto_config_id, **kwargs)  # noqa: E501
            return data

    def get_crypto_config_with_http_info(self, crypto_config_id, **kwargs):  # noqa: E501
        """Get the crypto configurations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_crypto_config_with_http_info(crypto_config_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :return: CryptoConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['crypto_config_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_crypto_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'crypto_config_id' is set
        if ('crypto_config_id' not in params or
                params['crypto_config_id'] is None):
            raise ValueError("Missing the required parameter `crypto_config_id` when calling `get_crypto_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'crypto_config_id' in params:
            path_params['cryptoConfigId'] = params['crypto_config_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/config/{cryptoConfigId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CryptoConfig',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def rapid_rotation_use_domain(self, use_domain_id, **kwargs):  # noqa: E501
        """Rapid expiration of existing use doamin and immediately replacment with an identical use domain containing fresh keys  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rapid_rotation_use_domain(use_domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str use_domain_id: (required)
        :param str optional_next_key_derivation_service_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.rapid_rotation_use_domain_with_http_info(use_domain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.rapid_rotation_use_domain_with_http_info(use_domain_id, **kwargs)  # noqa: E501
            return data

    def rapid_rotation_use_domain_with_http_info(self, use_domain_id, **kwargs):  # noqa: E501
        """Rapid expiration of existing use doamin and immediately replacment with an identical use domain containing fresh keys  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rapid_rotation_use_domain_with_http_info(use_domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str use_domain_id: (required)
        :param str optional_next_key_derivation_service_id:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['use_domain_id', 'optional_next_key_derivation_service_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rapid_rotation_use_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'use_domain_id' is set
        if ('use_domain_id' not in params or
                params['use_domain_id'] is None):
            raise ValueError("Missing the required parameter `use_domain_id` when calling `rapid_rotation_use_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'use_domain_id' in params:
            path_params['useDomainId'] = params['use_domain_id']  # noqa: E501

        query_params = []
        if 'optional_next_key_derivation_service_id' in params:
            query_params.append(('optionalNextKeyDerivationServiceId', params['optional_next_key_derivation_service_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/useDomain/{useDomainId}/rapidRotation', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_use_domain(self, use_domain_id, **kwargs):  # noqa: E501
        """Delete a fully expired use domain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_use_domain(use_domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str use_domain_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_use_domain_with_http_info(use_domain_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_use_domain_with_http_info(use_domain_id, **kwargs)  # noqa: E501
            return data

    def remove_use_domain_with_http_info(self, use_domain_id, **kwargs):  # noqa: E501
        """Delete a fully expired use domain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_use_domain_with_http_info(use_domain_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str use_domain_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['use_domain_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_use_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'use_domain_id' is set
        if ('use_domain_id' not in params or
                params['use_domain_id'] is None):
            raise ValueError("Missing the required parameter `use_domain_id` when calling `remove_use_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'use_domain_id' in params:
            path_params['useDomainId'] = params['use_domain_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/useDomain/{useDomainId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_crypto_config(self, crypto_config_id, updated_crypto_config, **kwargs):  # noqa: E501
        """Update the crypto configuration, ONLY the clientKeyType clientKeyBitlength, and clientKeyTTL fields.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_crypto_config(crypto_config_id, updated_crypto_config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :param CryptoConfig updated_crypto_config: (required)
        :return: CryptoConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_crypto_config_with_http_info(crypto_config_id, updated_crypto_config, **kwargs)  # noqa: E501
        else:
            (data) = self.update_crypto_config_with_http_info(crypto_config_id, updated_crypto_config, **kwargs)  # noqa: E501
            return data

    def update_crypto_config_with_http_info(self, crypto_config_id, updated_crypto_config, **kwargs):  # noqa: E501
        """Update the crypto configuration, ONLY the clientKeyType clientKeyBitlength, and clientKeyTTL fields.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_crypto_config_with_http_info(crypto_config_id, updated_crypto_config, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :param CryptoConfig updated_crypto_config: (required)
        :return: CryptoConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['crypto_config_id', 'updated_crypto_config']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_crypto_config" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'crypto_config_id' is set
        if ('crypto_config_id' not in params or
                params['crypto_config_id'] is None):
            raise ValueError("Missing the required parameter `crypto_config_id` when calling `update_crypto_config`")  # noqa: E501
        # verify the required parameter 'updated_crypto_config' is set
        if ('updated_crypto_config' not in params or
                params['updated_crypto_config'] is None):
            raise ValueError("Missing the required parameter `updated_crypto_config` when calling `update_crypto_config`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'crypto_config_id' in params:
            path_params['cryptoConfigId'] = params['crypto_config_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'updated_crypto_config' in params:
            body_params = params['updated_crypto_config']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/config/{cryptoConfigId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CryptoConfig',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_crypto_config_fallback_to_cloud(self, use_domain_id, fallback_to_cloud, **kwargs):  # noqa: E501
        """Update an existing crypto config's asymmetricKeyTTL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_crypto_config_fallback_to_cloud(use_domain_id, fallback_to_cloud, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str use_domain_id: (required)
        :param bool fallback_to_cloud: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_crypto_config_fallback_to_cloud_with_http_info(use_domain_id, fallback_to_cloud, **kwargs)  # noqa: E501
        else:
            (data) = self.update_crypto_config_fallback_to_cloud_with_http_info(use_domain_id, fallback_to_cloud, **kwargs)  # noqa: E501
            return data

    def update_crypto_config_fallback_to_cloud_with_http_info(self, use_domain_id, fallback_to_cloud, **kwargs):  # noqa: E501
        """Update an existing crypto config's asymmetricKeyTTL  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_crypto_config_fallback_to_cloud_with_http_info(use_domain_id, fallback_to_cloud, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str use_domain_id: (required)
        :param bool fallback_to_cloud: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['use_domain_id', 'fallback_to_cloud']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_crypto_config_fallback_to_cloud" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'use_domain_id' is set
        if ('use_domain_id' not in params or
                params['use_domain_id'] is None):
            raise ValueError("Missing the required parameter `use_domain_id` when calling `update_crypto_config_fallback_to_cloud`")  # noqa: E501
        # verify the required parameter 'fallback_to_cloud' is set
        if ('fallback_to_cloud' not in params or
                params['fallback_to_cloud'] is None):
            raise ValueError("Missing the required parameter `fallback_to_cloud` when calling `update_crypto_config_fallback_to_cloud`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'use_domain_id' in params:
            path_params['useDomainId'] = params['use_domain_id']  # noqa: E501

        query_params = []
        if 'fallback_to_cloud' in params:
            query_params.append(('fallbackToCloud', params['fallback_to_cloud']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/useDomain/{useDomainId}/enableKDSFallbackToCloud', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_crypto_config_selector_scheme(self, crypto_config_id, new_selector_scheme, **kwargs):  # noqa: E501
        """Update an existing crypto config's domainSelectorScheme  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_crypto_config_selector_scheme(crypto_config_id, new_selector_scheme, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :param str new_selector_scheme: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_crypto_config_selector_scheme_with_http_info(crypto_config_id, new_selector_scheme, **kwargs)  # noqa: E501
        else:
            (data) = self.update_crypto_config_selector_scheme_with_http_info(crypto_config_id, new_selector_scheme, **kwargs)  # noqa: E501
            return data

    def update_crypto_config_selector_scheme_with_http_info(self, crypto_config_id, new_selector_scheme, **kwargs):  # noqa: E501
        """Update an existing crypto config's domainSelectorScheme  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_crypto_config_selector_scheme_with_http_info(crypto_config_id, new_selector_scheme, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str crypto_config_id: (required)
        :param str new_selector_scheme: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['crypto_config_id', 'new_selector_scheme']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_crypto_config_selector_scheme" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'crypto_config_id' is set
        if ('crypto_config_id' not in params or
                params['crypto_config_id'] is None):
            raise ValueError("Missing the required parameter `crypto_config_id` when calling `update_crypto_config_selector_scheme`")  # noqa: E501
        # verify the required parameter 'new_selector_scheme' is set
        if ('new_selector_scheme' not in params or
                params['new_selector_scheme'] is None):
            raise ValueError("Missing the required parameter `new_selector_scheme` when calling `update_crypto_config_selector_scheme`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'crypto_config_id' in params:
            path_params['cryptoConfigId'] = params['crypto_config_id']  # noqa: E501

        query_params = []
        if 'new_selector_scheme' in params:
            query_params.append(('newSelectorScheme', params['new_selector_scheme']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/config/{cryptoConfigId}/domainSelectorScheme', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_expire_use_domain(self, use_domain_id, inception_ttl, encryption_ttl, decryption_ttl, retention_ttl, **kwargs):  # noqa: E501
        """Chnage expiration of a use domain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_expire_use_domain(use_domain_id, inception_ttl, encryption_ttl, decryption_ttl, retention_ttl, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str use_domain_id: (required)
        :param int inception_ttl: (required)
        :param int encryption_ttl: (required)
        :param int decryption_ttl: (required)
        :param int retention_ttl: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_expire_use_domain_with_http_info(use_domain_id, inception_ttl, encryption_ttl, decryption_ttl, retention_ttl, **kwargs)  # noqa: E501
        else:
            (data) = self.update_expire_use_domain_with_http_info(use_domain_id, inception_ttl, encryption_ttl, decryption_ttl, retention_ttl, **kwargs)  # noqa: E501
            return data

    def update_expire_use_domain_with_http_info(self, use_domain_id, inception_ttl, encryption_ttl, decryption_ttl, retention_ttl, **kwargs):  # noqa: E501
        """Chnage expiration of a use domain  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_expire_use_domain_with_http_info(use_domain_id, inception_ttl, encryption_ttl, decryption_ttl, retention_ttl, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str use_domain_id: (required)
        :param int inception_ttl: (required)
        :param int encryption_ttl: (required)
        :param int decryption_ttl: (required)
        :param int retention_ttl: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['use_domain_id', 'inception_ttl', 'encryption_ttl', 'decryption_ttl', 'retention_ttl']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_expire_use_domain" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'use_domain_id' is set
        if ('use_domain_id' not in params or
                params['use_domain_id'] is None):
            raise ValueError("Missing the required parameter `use_domain_id` when calling `update_expire_use_domain`")  # noqa: E501
        # verify the required parameter 'inception_ttl' is set
        if ('inception_ttl' not in params or
                params['inception_ttl'] is None):
            raise ValueError("Missing the required parameter `inception_ttl` when calling `update_expire_use_domain`")  # noqa: E501
        # verify the required parameter 'encryption_ttl' is set
        if ('encryption_ttl' not in params or
                params['encryption_ttl'] is None):
            raise ValueError("Missing the required parameter `encryption_ttl` when calling `update_expire_use_domain`")  # noqa: E501
        # verify the required parameter 'decryption_ttl' is set
        if ('decryption_ttl' not in params or
                params['decryption_ttl'] is None):
            raise ValueError("Missing the required parameter `decryption_ttl` when calling `update_expire_use_domain`")  # noqa: E501
        # verify the required parameter 'retention_ttl' is set
        if ('retention_ttl' not in params or
                params['retention_ttl'] is None):
            raise ValueError("Missing the required parameter `retention_ttl` when calling `update_expire_use_domain`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'use_domain_id' in params:
            path_params['useDomainId'] = params['use_domain_id']  # noqa: E501

        query_params = []
        if 'inception_ttl' in params:
            query_params.append(('inceptionTTL', params['inception_ttl']))  # noqa: E501
        if 'encryption_ttl' in params:
            query_params.append(('encryptionTTL', params['encryption_ttl']))  # noqa: E501
        if 'decryption_ttl' in params:
            query_params.append(('decryptionTTL', params['decryption_ttl']))  # noqa: E501
        if 'retention_ttl' in params:
            query_params.append(('retentionTTL', params['retention_ttl']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['header']  # noqa: E501

        return self.api_client.call_api(
            '/crypto/useDomain/{useDomainId}/updateExpire', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# -*- coding: utf-8 -*-
"""Example Module docstrings.
This module ...
Example:
    Examples can be given using either the ``Example`` or ``Examples``
    sections. Sections support any reStructuredText formatting, including
    literal blocks::
        $ python example_google.py
Section breaks are created by resuming unindented text. Section breaks
are also implicitly created anytime a new section starts.
Attributes:
    module_level_variable1 (int): Module level variables may be documented in
        either the ``Attributes`` section of the module docstring, or in an
        inline docstring immediately following the variable.
        Either form is acceptable, but the two should not be mixed. Choose
        one convention to document module level variables and be consistent
        with it.
"""

from abc import ABC, abstractmethod

class PeacemakrCryptoSDK(ABC):

    @abstractmethod
    def register(self):
        """Registers to Peacemakr as a client.

        The persister is used to detect prior registrations on this client, so safe
        to call multiple times. Once a successful invocation of Register is executed once, subsequent calls become a
        noop. One successful call is required before any cryptographic use of this SDK.

        Registration may fail with invalid apiKey, missing network connectivity, or an invalid persister. On failure,
        take corrections action and invoke again.

        Raises:
            AttributeError: TODO to be modified later.
            ValueError: ...

        """
        pass


    @abstractmethod
    def sync(self):
        """Sync all available keys for this client.

        This invocation will help performance of subsequent encryption and decryption calls.

        Sync may fail, if registration was not invoked, if there's network connectivity issues, or
        unexpected authorization issues.

        Raises:
            AttributeError: TODO to be modified later.
            ValueError: ...

        """
        pass


    @abstractmethod
    def encrypt(self, plain_text: bytes) -> bytes:
        """Encrypt the plaintext, using a random available usedomain.

        Args:
            plain_text (bytes): Plaintext bytes to encrypt.

        Returns:
            bytes: Opaquely packaged ciphertext.

        Raises:
            AttributeError: TODO to be modified later.
            ValueError: ...

        """
        pass


    @abstractmethod
    def encrypt_in_domain(self, plain_text: bytes, use_domain_name: str) -> bytes:
        """
        Encrypt the plaintext, but restrict which keys may be used to a Use Domain of this specific name. Names of Use
        Domains are not unique, and this non-unique property of your Organization's Use Domains allows for graceful
        rotation of encryption keys off of old (retiring, stale, or compromised) Use Domains, simply by creating a new
        Use Domain with the same name. The transitional purity, both Use Domains may be selected for encryption use by
        clients restricted to one particular name. Then, retiring of one of the two Use Domains is possible without
        disrupting your deployed application.

        Args:
            plain_text (bytes): Plaintext to encrypt.
            use_domain_name (str): Non-unique User Domain of your organization's.

        Returns:
            bytes: Opaquely packaged ciphertext.

        Raises:
            AttributeError: TODO to be modified later.
            ValueError: ...

        """
        pass


    @abstractmethod
    def decrypt(self, cipher_text: bytes) -> bytes:
        """
        Decrypt the opaquely packaged ciphertext and return the original plain text.

        Args:
            cipher_text (bytes): CipherText to decrypt.

        Returns:
            bytes: decrypted plaintext in bytes

        Raises:
            AttributeError: TODO to be modified later.
            ValueError: ...

        """
        pass



from peacemakr.exception.core_crypto import CoreCryptoError
from peacemakr.exception.failed_to_download_key import FailedToDownloadKeyError
from peacemakr.exception.invalid_cipher import InvalidCipherError
from peacemakr.exception.missing_api_key import MissingAPIKeyError
from peacemakr.exception.missing_client_name import MissingClientNameError
from peacemakr.exception.missing_persister import MissingPersisterError
from peacemakr.exception.no_valid_use_domains_for_decryption import NoValidUseDomainsForDecryptionError
from peacemakr.exception.no_valid_use_domains_for_encryption import NoValidUseDomainsForEncryptionError
from peacemakr.exception.persistence_layer_corruption_detected import PersistenceLayerCorruptionDetectedError
from peacemakr.exception.server import ServerError
from peacemakr.exception.unrecoverable_clock_skew_detected import UnrecoverableClockSkewDetectedError
from peacemakr.exception.peacemakr import PeacemakrError



from peacemakr.persister_base import Persister

class InMemoryPersister(Persister):

    def __init__(self):
        self.__persister = {}

    def save(self, key, value):
        self.__persister[key] = value

    def load(self, key):
        return self.__persister[key]

    def exists(self, key):
        return key in self.__persister.keys()

    def key_nums(self):
        return len(self.__persister.keys())



from peacemakr.impl.crypto_impl import CryptoImpl

def get_crypto_sdk(api_key="", client_name="", peacemakr_hostname="", persister=None, logger=None):
  return CryptoImpl(api_key=api_key, client_name=client_name, peacemakr_hostname=peacemakr_hostname, persister=persister, logger=logger)



# coding: utf-8

"""
    Peacemakr

    This API describes the Peacemakr services, which enable seamless application layer encryption and verification.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from peacemakr.generated.models.public_key import PublicKey  # noqa: F401,E501


class Client(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'sdk': 'str',
        'preferred_public_key_id': 'str',
        'public_keys': 'list[PublicKey]'
    }

    attribute_map = {
        'id': 'id',
        'sdk': 'sdk',
        'preferred_public_key_id': 'preferredPublicKeyId',
        'public_keys': 'publicKeys'
    }

    def __init__(self, id=None, sdk=None, preferred_public_key_id=None, public_keys=None):  # noqa: E501
        """Client - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._sdk = None
        self._preferred_public_key_id = None
        self._public_keys = None
        self.discriminator = None

        self.id = id
        if sdk is not None:
            self.sdk = sdk
        if preferred_public_key_id is not None:
            self.preferred_public_key_id = preferred_public_key_id
        self.public_keys = public_keys

    @property
    def id(self):
        """Gets the id of this Client.  # noqa: E501


        :return: The id of this Client.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Client.


        :param id: The id of this Client.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def sdk(self):
        """Gets the sdk of this Client.  # noqa: E501


        :return: The sdk of this Client.  # noqa: E501
        :rtype: str
        """
        return self._sdk

    @sdk.setter
    def sdk(self, sdk):
        """Sets the sdk of this Client.


        :param sdk: The sdk of this Client.  # noqa: E501
        :type: str
        """

        self._sdk = sdk

    @property
    def preferred_public_key_id(self):
        """Gets the preferred_public_key_id of this Client.  # noqa: E501

        of all the public keys KeyDeriver's should deliver to this public key - it is also the most recently added public key  # noqa: E501

        :return: The preferred_public_key_id of this Client.  # noqa: E501
        :rtype: str
        """
        return self._preferred_public_key_id

    @preferred_public_key_id.setter
    def preferred_public_key_id(self, preferred_public_key_id):
        """Sets the preferred_public_key_id of this Client.

        of all the public keys KeyDeriver's should deliver to this public key - it is also the most recently added public key  # noqa: E501

        :param preferred_public_key_id: The preferred_public_key_id of this Client.  # noqa: E501
        :type: str
        """

        self._preferred_public_key_id = preferred_public_key_id

    @property
    def public_keys(self):
        """Gets the public_keys of this Client.  # noqa: E501


        :return: The public_keys of this Client.  # noqa: E501
        :rtype: list[PublicKey]
        """
        return self._public_keys

    @public_keys.setter
    def public_keys(self, public_keys):
        """Sets the public_keys of this Client.


        :param public_keys: The public_keys of this Client.  # noqa: E501
        :type: list[PublicKey]
        """
        if public_keys is None:
            raise ValueError("Invalid value for `public_keys`, must not be `None`")  # noqa: E501

        self._public_keys = public_keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Client, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Client):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
